function [DImatrix,fs]= DI (filename,degreestheta,degreesphi,theta,phi,t1,t2,f1,f2,nfft,pos,a)
%------------------------------------------------------
%
%This function calculates the Directivity Index in one direction. For this
%calculation, the rest of the measured orientations should be loaded. 
%
%The instruction has to be like:
%[DImatrix]= DI (filename,degreestheta,degreesphi,theta,phi,t1,t2)
%
%- Before and after the filename: '
%- degreestheta and degreesphi are the steps in the measurements. 
%- theta and phi form the direction where the DI is desired to be calculated 
%- t1 and t2 mean start and end of the window within the fft is calculated
%
% DImatrix is a vector of length fs/2 (usually 24000 due to fs=48000)
%
%
%
%    Diego Ivars
%
%------------------------------------------------------






nfiles = 360/degreesphi;
nfiles2 = 180/degreestheta+1;
represmatrix=zeros(nfiles2,nfiles+1,nfft/2);
filenamestart = [filename,'_'];
%theta is defined from 0 to 180
for ii = 1:nfiles
        filenumb=(ii-1)*degreesphi;
         for jj=1:nfiles2
            filenumb2=(jj-1)*degreestheta;
      
            filename1 = [filenamestart,int2str(filenumb),'_',int2str(filenumb2),'_Ch1.wmb'];
            filename2 = [filenamestart,int2str(filenumb),'_',int2str(filenumb2),'_Ch2.wmb'];
            filename3 = [filenamestart,int2str(filenumb),'_',int2str(filenumb2),'_Ch3.wmb'];
            filename4 = [filenamestart,int2str(filenumb),'_',int2str(filenumb2),'_Ch4.wmb'];

            if(exist(filename1))
                commandstr = ['[ir,fs] = loadimp(','''',filename1,'''',');'];
                f=1;
            elseif(exist(filename2))
                commandstr = ['[ir,fs] = loadimp(','''',filename2,'''',');'];
                f=2;
            elseif(exist(filename3))
                commandstr = ['[ir,fs] = loadimp(','''',filename3,'''',');'];
                f=3;
            elseif(exist(filename4))
                commandstr = ['[ir,fs] = loadimp(','''',filename4,'''',');'];
                f=4;
            end
                 
            eval(commandstr)

            ir=center(ir,pos);
        
            h1=ir./(20*10^(-6));
            try
                h1=h1(round(t1*fs)+1:round(t2*fs)+1);
            catch
                errordlg('Error. It could be caused by the File name (check SETUP)','Error');
            end
            

            y=abs(fft(h1,nfft));
            reprod=y(1:nfft/2);
            reprod=reprod(:);
            reprod=reprod';
       
            
            if f==1
                reprod=reprod./a(1,:);
            elseif f==2
                reprod=reprod./a(2,:);
            elseif f==3
                reprod=reprod./a(3,:);
            elseif f==4
                reprod=reprod./a(4,:);
            end
        

            
            
            fclose('all'); % Close all open files

            
        
            represmatrix(jj,ii,:)=reprod.^2;
        
         end        
        
end


represmatrix(:,(nfiles+1),:)=represmatrix(:,1,:);%if this is not placed,
                                    %the courve is not completely closed.    
                                    

%calculation of the double summatory (it is the same sum for each frequency)
B=(round(f2*nfft/fs)-round(f1*nfft/fs))/3;

disp('0%...');
Isum=zeros(1,length(reprod));
for i=round(f1*nfft/fs):round(f2*nfft/fs)
    
    if(i==round(f1*nfft/fs)+round(B))
        disp('33%...');
    elseif(i==round(f1*nfft/fs)+2*round(B))
        disp('66%...');
    elseif(i==round(f2*nfft/fs))
        disp('100%...');
    end
    
    for j=1:nfiles+1
        for k=1:nfiles2
            Isum(1,i)=Isum(1,i)+represmatrix(k,j,i)*sin((k-1)*degreestheta*pi/180);
        end
    end
    Isum(1,i)=Isum(1,i)/(4*pi)*(degreestheta*(pi/180)*degreesphi*(pi/180));
end
DImatrix=zeros(1,length(reprod));

for i=round(f1*nfft/fs):round(f2*nfft/fs)
    DImatrix(1,i)=10*log10(represmatrix((theta/degreestheta+1),(phi/degreesphi+1),i)/Isum(1,i));
end

