function [theta, phi, DIvect,fs]= orient (filename,degreestheta,degreesphi,t1,t2,f1,f2,nfft,pos,a)
%------------------------------------------------------
%
%This function calculates the most suitable orientation in a loudspeaker,
%understanding most suitable as the orientation on which the Directivity
%Index is close to zero in all the frequency range. 
%
%
%The instruction has to be like:
%[theta, phi, DIvect]= orient (filename,degreestheta,degreesphi,t1,t2,f1,f2)
%
%- Before and after the filename: '
%- degreestheta and degreesphi are the steps in the measurements. 
%- t1 and t2 mean start and end of the window within the fft is calculated
%- f1 and f2 represent the frequency range the result will be based on
%
% Results:
%   - theta and phi: coordinates of the suitable orientation
%   - DIvect: vector of (1, f1:f2) where the DI of the suitable orientation is
%   stored
%
%
%     Diego Ivars
%
%------------------------------------------------------





nfiles = 360/degreesphi;
nfiles2 = 180/degreestheta+1;
represmatrix=zeros(nfiles2,nfiles+1,nfft/2);
filenamestart = [filename,'_'];
%theta is defined from 0 to 180
disp('Opening files...');
for ii = 1:nfiles
    disp(['phi=' num2str((ii-1)*degreesphi)]);
        filenumb=(ii-1)*degreesphi;
         for jj=1:nfiles2
            filenumb2=(jj-1)*degreestheta;
            
            
            
            %filename = [filenamestart,int2str(filenumb),'_',int2str(filenumb2),'.wmb'];
            
            
            filename1 = [filenamestart,int2str(filenumb),'_',int2str(filenumb2),'_Ch1.wmb'];
            filename2 = [filenamestart,int2str(filenumb),'_',int2str(filenumb2),'_Ch2.wmb'];
            filename3 = [filenamestart,int2str(filenumb),'_',int2str(filenumb2),'_Ch3.wmb'];
            filename4 = [filenamestart,int2str(filenumb),'_',int2str(filenumb2),'_Ch4.wmb'];

            if(exist(filename1))
                commandstr = ['[ir,fs] = loadimp(','''',filename1,'''',');'];
                f=1;
            elseif(exist(filename2))
                commandstr = ['[ir,fs] = loadimp(','''',filename2,'''',');'];
                f=2;
            elseif(exist(filename3))
                commandstr = ['[ir,fs] = loadimp(','''',filename3,'''',');'];
                f=3;
            elseif(exist(filename4))
                commandstr = ['[ir,fs] = loadimp(','''',filename4,'''',');'];
                f=4;
            end
                 
            
            %commandstr = ['[ir,fs] = loadimp(','''',filename,'''',');'];
            eval(commandstr)
            

            ir=center(ir,pos);
           
 

        
            h1=ir./(20*10^(-6));
            h1=h1(round(t1*fs)+1:round(t2*fs)+1);
            
%             h1=h1(t1*fs:t2*fs);
%             tam=size(h1);
%             h2=zeros(fs-tam(1),1);
%             h1=[h1' h2'];
%             y=abs(fft(h1'));
%             reprod=(y(1:round(fs/2)));%it keeps the left part of the spectrum
%             %reprod contains the pressure in every frequency (steps of 1Hz)
%             %from 0 to 24000.
            %df=fs/nfft;
            y=abs(fft(h1,nfft));
            reprod=y(1:nfft/2);
            reprod=reprod(:);
            reprod=reprod';
         
            
            if f==1
                reprod=reprod./a(1,:);
            elseif f==2
                reprod=reprod./a(2,:);
            elseif f==3
                reprod=reprod./a(3,:);
            elseif f==4
                reprod=reprod./a(4,:);
            end
        
            fclose('all'); % Close all open files


            
        
            represmatrix(jj,ii,:)=reprod.^2;
        
         end
        
        
end




represmatrix(:,(nfiles+1),:)=represmatrix(:,1,:);%if this is not placed,
                                    %the courve is not completely closed.    
                                    

%calculation of the double summatory (it is the same sum for each frequency)
Isum=zeros(1,length(reprod));

disp('-------------------------------------------------------------');
disp('Calculating DI double summatory. 1/3');
disp('0%...');
B=(round(f2*nfft/fs)-round(f1*nfft/fs))/10;

for i=round(f1*nfft/fs):round(f2*nfft/fs)
%for i=1:length(reprod)

    if(i==round(f1*nfft/fs)+round(B))
        disp('10%...');
    elseif(i==round(f1*nfft/fs)+2*round(B))
        disp('20%...');
    elseif(i==round(f1*nfft/fs)+3*round(B))
        disp('30%...');
    elseif(i==round(f1*nfft/fs)+4*round(B))
        disp('40%...');
    elseif(i==round(f1*nfft/fs)+5*round(B))
        disp('50%...');
    elseif(i==round(f1*nfft/fs)+6*round(B))
        disp('60%...');
    elseif(i==round(f1*nfft/fs)+7*round(B))
        disp('70%...');
    elseif(i==round(f1*nfft/fs)+8*round(B))
        disp('80%...');
    elseif(i==round(f1*nfft/fs)+9*round(B))
        disp('90%...');
    elseif(i==round(f2*nfft/fs))
        disp('100%...');
    end
        
        
    for j=1:nfiles+1
        for k=1:nfiles2
            Isum(1,i)=Isum(1,i)+represmatrix(k,j,i)*sin((k-1)*degreestheta*pi/180);
        end
    end
    Isum(1,i)=Isum(1,i)/(4*pi)*(degreestheta*(pi/180)*degreesphi*(pi/180));
end
pause(0.02);
%DImatrix=zeros(1,length(reprod));

disp('-------------------------------------------------------------');
disp('Calculating DI in each direction. 2/3');
disp('0%...');
cont=0;
DImatrix=zeros(nfiles2,nfiles+1,length(reprod));
for i=round(f1*nfft/fs):round(f2*nfft/fs)
    
    if(i==round(f1*nfft/fs)+round(B))
        disp('10%...');
    elseif(i==round(f1*nfft/fs)+2*round(B))
        disp('20%...');
    elseif(i==round(f1*nfft/fs)+3*round(B))
        disp('30%...');
    elseif(i==round(f1*nfft/fs)+4*round(B))
        disp('40%...');
    elseif(i==round(f1*nfft/fs)+5*round(B))
        disp('50%...');
    elseif(i==round(f1*nfft/fs)+6*round(B))
        disp('60%...');
    elseif(i==round(f1*nfft/fs)+7*round(B))
        disp('70%...');
    elseif(i==round(f1*nfft/fs)+8*round(B))
        disp('80%...');
    elseif(i==round(f1*nfft/fs)+9*round(B))
        disp('90%...');
    elseif(i==round(f2*nfft/fs))
        disp('100%...');
   end
    
   
    for j=1:nfiles+1
        for k=1:nfiles2
            DImatrix(k,j,i)=10*log10(represmatrix(k,j,i)/Isum(1,i));
        end
    end
    cont=cont+1;
    if cont==200
        pause(0.02);%si quito este pause no va!!!!!!!!!!!!!
        cont=0;
    end
end
pause(0.02);
[a b c]=size(DImatrix);
sum=zeros(a,b);
minimum=inf;
%calculates the integral of the DI courve

disp('-------------------------------------------------------------');
disp('Seeking suitable DI. 3/3');

for j=1:nfiles+1
    for k=1:nfiles2
        for i=round(f1*nfft/fs):round(f2*nfft/fs)
            sum(k,j)=sum(k,j)+abs(DImatrix(k,j,i));
        end
        if sum(k,j)<minimum
            theta=k;
            phi=j;
            minimum=sum(k,j);
        end
        
    end
    pause(0.02);
end
DIvect=zeros(1,round(f2*nfft/fs));
for i=round(f1*nfft/fs):round(f2*nfft/fs)
    DIvect(1,i)=DImatrix(theta,phi,i);
end
disp('Process completed succesfully');
theta=(theta-1)*degreestheta;
phi=(phi-1)*degreesphi;


