function [represmatrix,fs]= radiatdiagram(filename,degreestheta,anglephi,t1,t2,freq,nfft,pos,a)
%--------------------------------------------------------------------------
%
%"radiatdiagram" is a program developed to get the frequency response of a 
% loudspeaker in different directions in one specific frequency. It could
% be used to represent polar diagrams.
%
%It works with the measurements (files .wmb) obtained with WinMLS. 
%
%
%The way to call it:
%
%[represmatrix]= radiatdiagram(filename,degreestheta,anglephi,t1,t2,freq)
%
%
%- Before and after the filename: ' 
%- degreestheta is the step advanced in every measurement
%- anglephi is the plane where the representation will be made
%- t1 and t2 mean start and end of the window within the fft is calculated
%- freq is the frequency desired
%
%
%-represmatrix will contain a vector. The size of the vector will be 
%(2*180/degreestheta+1,1). 
%represmatrix(1,1) contains the dB(SPL) of theta=0,phi=anglephi and f=freq
%represmatrix(2,1) contains the dB(SPL) of theta=degreestheta,phi=anglephi 
%           and f=freq
%represmatrix(3,1) contains the dB(SPL) of theta=2*degreestheta,phi=anglephi
%           and f=freq
% ...
%
%
%
%
%   Diego Ivars
%
%
%--------------------------------------------------------------------------







nfiles = 180/degreestheta ;
filenamestart = [filename,'_'];
%theta is defined from 0 to 180.

%with this for, files with phi=anglephi and
%theta=0,degreestheta,2*degreestheta... 180-degreestheta will be read.
for ii = 1:nfiles
        filenumb=(ii-1)*degreestheta;
        
        
        filename1 = [filenamestart,int2str(anglephi),'_',int2str(filenumb),'_Ch1.wmb'];
        filename2 = [filenamestart,int2str(anglephi),'_',int2str(filenumb),'_Ch2.wmb'];
        filename3 = [filenamestart,int2str(anglephi),'_',int2str(filenumb),'_Ch3.wmb'];
        filename4 = [filenamestart,int2str(anglephi),'_',int2str(filenumb),'_Ch4.wmb'];

        if(exist(filename1))
            commandstr = ['[ir,fs] = loadimp(','''',filename1,'''',');'];
            f=1;
        elseif(exist(filename2))
            commandstr = ['[ir,fs] = loadimp(','''',filename2,'''',');'];
            f=2;
        elseif(exist(filename3))
            commandstr = ['[ir,fs] = loadimp(','''',filename3,'''',');'];
            f=3;
        elseif(exist(filename4))
            commandstr = ['[ir,fs] = loadimp(','''',filename4,'''',');'];
            f=4;
        end
                 
        
        
        

        
        eval(commandstr)

        fclose('all'); % Close all open files

        ir=center(ir,pos);

        
    
        h1=ir./(20*10^(-6));
        try
            h1=h1(round(t1*fs)+1:round(t2*fs)+1);
        catch
            errordlg('Error. It could be caused by the File name (check SETUP)','Error');
        end


        y=abs(fft(h1,nfft));
        reprod=y(1:nfft/2);
        reprod=reprod(:);
        reprod=reprod';      
        
        
        %Calibration
        if f==1
            reprod=reprod./a(1,:);
        elseif f==2
            reprod=reprod./a(2,:);
        elseif f==3
            reprod=reprod./a(3,:);
        elseif f==4
            reprod=reprod./a(4,:);
         end

        reprod=20*log10(reprod);
        

        
        %vertical vector is needed
        [c,b]=size(reprod);
        if c==1
            reprod=reprod';
        end
        

       
        if ii==1
            represmatrix=zeros((nfiles*2+1),1);
        end

        
        %to make the values under 60dB equal to 60 dB because of the
        %representation
        
        for kk=1:length(reprod)
            if reprod(kk,1)<60
                reprod(kk,1)=60;
            end
        end
        
        reprod=reprod-60;
       
        
        represmatrix(ii,1)=reprod(round(freq*nfft/fs),1);
        
        
end


%now from 180 to 360 

%with this for, files with phi=anglephi+180 and
%theta=180,180-degreestheta,180-2*degreestheta... 0 will be read.
for ii = 1:nfiles
        filenumb=180-(ii-1)*degreestheta;
        if anglephi<180
            filename = [filenamestart,int2str(anglephi+180),'_',int2str(filenumb)];
            
        else
            filename = [filenamestart,int2str(anglephi-180),'_',int2str(filenumb)];
        end
        
        
        
        filename1 = [filename,'_Ch1.wmb'];
        filename2 = [filename,'_Ch2.wmb'];
        filename3 = [filename,'_Ch3.wmb'];
        filename4 = [filename,'_Ch4.wmb'];

        if(exist(filename1))
            commandstr = ['[ir,fs] = loadimp(','''',filename1,'''',');'];
            f=1;
        elseif(exist(filename2))
            commandstr = ['[ir,fs] = loadimp(','''',filename2,'''',');'];
            f=2;
        elseif(exist(filename3))
            commandstr = ['[ir,fs] = loadimp(','''',filename3,'''',');'];
            f=3;
        elseif(exist(filename4))
            commandstr = ['[ir,fs] = loadimp(','''',filename4,'''',');'];
            f=4;
        end
        
        

        eval(commandstr)


        ir=center(ir,pos);

        
        h1=ir./(20*10^(-6));
        try
            h1=h1(round(t1*fs)+1:round(t2*fs)+1);
        catch
            errordlg('Error. It could be caused by the File name (check SETUP)','Error');
        end


        y=abs(fft(h1,nfft));
        reprod=y(1:nfft/2);
        reprod=reprod(:);
        reprod=reprod';    
        
        
        %Calibration
        reprod=reprod(:);
        reprod=reprod';      
        
        if f==1
            reprod=reprod./a(1,:);
        elseif f==2
            reprod=reprod./a(2,:);
        elseif f==3
            reprod=reprod./a(3,:);
        elseif f==4
            reprod=reprod./a(4,:);
         end
        
        
        
        
        
        
        
        reprod=20*log10(reprod);


        
        
        [ac,b]=size(reprod);
        if ac==1
            reprod=reprod';
        end
        

        
        %to make the values under 60dB equal to 60 dB because of the
        %representation
      
        for kk=1:length(reprod)
            if reprod(kk,1)<60
                reprod(kk,1)=60;
            end
        end
        
        reprod=reprod-60;
       
        
        represmatrix(ii+nfiles,1)=reprod(round(freq*nfft/fs),1);
        
        
end


represmatrix((2*nfiles+1),1)=represmatrix(1,1);%if this is not placed,
                                    %the courve in the representation 
                                    %is not completely closed.

 