function [represmatrix,fs]= repres3d (varargin)
%--------------------------------------------------------------------------
%
%repres3d:
%This function gets the frequency response of one or several orientations.
%The calling of this function should be:
%    [represmatrix]=repres3d(filename,degreestheta,degreesphi,t1,t2,theta,phi)
%
%- Before and after the filename: '
%- degreestheta and degreesphi are the steps in the measurements. 
%- t1 and t2 mean start and end of the window within the fft is calculated
%- theta and phi represent the direction which the frequecy response
%will be calculated on
%
%
%It works in three different ways:
%
%   - phi introduced, theta not defined('-'). The result is a matrix of
%   (180/degreestheta+1,fs/2) where all the frequency responses are stored.
%   The first row contains the frequency response of theta=0, second
%   theta=degreestheta, third theta=2*degreestheta,... last theta=180.
%
%   - theta introduced, phi not defined('-'). The result is a matrix of
%   (360/degreesphi+1,fs/2) where all the frequency responses are stored.
%   The first row contains the frequency response of phi=0, second
%   phi=degreesphi, third phi=2*degreesphi,... last phi=360-degreesphi.
%
%   - Both are introduced. The result is a vector of length fs/2 that
%   contains the frequency response in that direction.
%
%
%
%    Diego Ivars
%
%--------------------------------------------------------------------------

[cax,args,nargs] = axescheck(varargin{:});
error(nargchk(10,10,nargs,'struct'));


if nargs < 10 || nargs > 10
    error('MATLAB:repres3d:InvalidInput', 'Requires 10 data arguments.')
else
    filename = args{1};
    degreestheta = args{2};
    degreesphi = args {3};
    t1 = args{4};
    t2 = args{5};
    theta=args{6};
    phi=args{7};
    nfft=args{8};
    pos=args{9};
    a=args{10};
    
    
    
    
        
     
    if (strcmp(theta,'-')) %Representation with theta variable
        nfiles = 180/degreestheta+1;
        filenamestart = [filename,'_'];

        for ii = 1:nfiles
            
            filenumb=(ii-1)*degreestheta;

            
            filename1 = [filenamestart,int2str(phi),'_',int2str(filenumb),'_Ch1.wmb'];
            filename2 = [filenamestart,int2str(phi),'_',int2str(filenumb),'_Ch2.wmb'];
            filename3 = [filenamestart,int2str(phi),'_',int2str(filenumb),'_Ch3.wmb'];
            filename4 = [filenamestart,int2str(phi),'_',int2str(filenumb),'_Ch4.wmb'];
            
            if(exist(filename1))
                commandstr = ['[ir,fs] = loadimp(','''',filename1,'''',');'];
                f=1;
            elseif(exist(filename2))
                commandstr = ['[ir,fs] = loadimp(','''',filename2,'''',');'];
                f=2;
            elseif(exist(filename3))
                commandstr = ['[ir,fs] = loadimp(','''',filename3,'''',');'];
                f=3;
            elseif(exist(filename4))
                commandstr = ['[ir,fs] = loadimp(','''',filename4,'''',');'];
                f=4;
            end
            
            eval(commandstr)

            fclose('all'); % Close all open files

            
            ir=center(ir,pos);



            h1=ir./(20*10^(-6));
            try
                h1=h1(round(t1*fs)+1:round(t2*fs)+1);
            catch
                errordlg('Error. It could be caused by the File name (check SETUP)','Error');
            end
            

            
            y=abs(fft(h1,nfft));
            reprod=y(1:nfft/2);

            %Calibration

            reprod=reprod(:);
            reprod=reprod';
            if f==1
                
                reprod=reprod./a(1,:);
            elseif f==2
                reprod=reprod./a(2,:);
            elseif f==3
                reprod=reprod./a(3,:);
            elseif f==4
                reprod=reprod./a(4,:);
             end

            reprod=20*log10(reprod);

            
            
          
            
            if ii==1
                represmatrix=zeros(nfiles,length(reprod));
            end
            
           
        
                represmatrix(ii,:)=reprod;
        
        
        end


    else
         if(strcmp(phi,'-')) %Representation with phi variable
            nfiles = 360/degreesphi;
            filenamestart = [filename,'_'];
 
             for ii = 1:nfiles
                 filenumb=(ii-1)*degreesphi;
                 
                filename1 = [filenamestart,int2str(filenumb),'_',int2str(phi),'_Ch1.wmb'];
                filename2 = [filenamestart,int2str(filenumb),'_',int2str(phi),'_Ch2.wmb'];
                filename3 = [filenamestart,int2str(filenumb),'_',int2str(phi),'_Ch3.wmb'];
                filename4 = [filenamestart,int2str(filenumb),'_',int2str(phi),'_Ch4.wmb'];

                if(exist(filename1))
                    commandstr = ['[ir,fs] = loadimp(','''',filename1,'''',');'];
                    f=1;
                elseif(exist(filename2))
                    commandstr = ['[ir,fs] = loadimp(','''',filename2,'''',');'];
                    f=2;
                elseif(exist(filename3))
                    commandstr = ['[ir,fs] = loadimp(','''',filename3,'''',');'];
                    f=3;
                elseif(exist(filename4))
                    commandstr = ['[ir,fs] = loadimp(','''',filename4,'''',');'];
                    f=4;
                end
                 
                 
                 

                 eval(commandstr)


                 fclose('all'); % Close all open files

         

                 ir=center(ir,pos);
   
                 

                h1=ir./(20*10^(-6));
                try
                    h1=h1(round(t1*fs)+1:round(t2*fs)+1);
                catch
                    errordlg('Error. It could be caused by the File name (check SETUP)','Error');
                end


                y=abs(fft(h1,nfft));
                reprod=y(1:nfft/2);

                %Calibration
                reprod=reprod(:);
                reprod=reprod';

                if f==1
                    reprod=reprod./a(1,:);
                elseif f==2
                    reprod=reprod./a(2,:);
                elseif f==3
                    reprod=reprod./a(3,:);
                elseif f==4
                    reprod=reprod./a(4,:);
                 end

                reprod=20*log10(reprod);





                 if ii==1
                     represmatrix=zeros(nfiles,length(reprod));
                 end

                     represmatrix(ii,:)=reprod;


             end

        
             
         else %both coordinates are introduced
            filenamestart = [filename,'_'];
          
            
            
            
            filename1 = [filenamestart,int2str(phi),'_',int2str(theta),'_Ch1.wmb'];
            filename2 = [filenamestart,int2str(phi),'_',int2str(theta),'_Ch2.wmb'];
            filename3 = [filenamestart,int2str(phi),'_',int2str(theta),'_Ch3.wmb'];
            filename4 = [filenamestart,int2str(phi),'_',int2str(theta),'_Ch4.wmb'];
            
            
            if(exist(filename1))
                commandstr = ['[ir,fs] = loadimp(','''',filename1,'''',');'];
                f=1;
            elseif(exist(filename2))
                commandstr = ['[ir,fs] = loadimp(','''',filename2,'''',');'];
                f=2;
            elseif(exist(filename3))
                commandstr = ['[ir,fs] = loadimp(','''',filename3,'''',');'];
                f=3;
            elseif(exist(filename4))
                commandstr = ['[ir,fs] = loadimp(','''',filename4,'''',');'];
                f=4;
            end

            eval(commandstr)
            fclose('all'); % Close all open files

            ir=center(ir,pos);
            
            h1=ir./(20*10^(-6));
            try
                h1=h1(round(t1*fs)+1:round(t2*fs)+1);
            catch
                errordlg('Error. It could be caused by the File name (check SETUP)','Error');
            end
            

            y=abs(fft(h1,nfft));
            reprod=y(1:nfft/2);

            %Calibration
            reprod=reprod(:);
            reprod=reprod';

            if f==1
                reprod=reprod./a(1,:);
            elseif f==2
                reprod=reprod./a(2,:);
            elseif f==3
                reprod=reprod./a(3,:);
            elseif f==4
                reprod=reprod./a(4,:);
             end

            reprod=20*log10(reprod);

            
            
            
            represmatrix=reprod;
            

        end
    end
end


